export default {
    "index": 25,
    "lineNumber": 1,
    "column": 26,
    "message": "The only valid meta property for new is 'new.target'"
};
